@@ -140,7 +140,7 @@ resp_retry_after <- function(resp) {
   val <- resp_header(resp, "Retry-After")
   if (is.null(val)) {
     NA
-  } else if (grepl(" ", val)) {
+  } else if (grepl(" ", val, fixed = TRUE)) {
     diff <- difftime(parse_http_date(val), resp_date(resp), units = "secs")
     as.numeric(diff)
   } else {
@@ -173,7 +173,9 @@ resp_link_url <- function(resp, rel) {
     return()
   }
 
-  links <- parse_link(resp_header(resp, "Link"))
+  headers <- resp_headers(resp)
+  link_headers <- headers[names(headers) == "Link"]
+  links <- unlist(lapply(link_headers, parse_link), recursive = FALSE)
   sel <- map_lgl(links, ~ .$rel == rel)
   if (sum(sel) != 1L) {
     return()
