@@ -8,7 +8,7 @@ bullets_with_header <- function(header, x) {
   as_simple <- function(x) {
     if (is.atomic(x) && length(x) == 1) {
       if (is.character(x)) {
-        paste0("'", x, "'")
+        paste0('"', x, '"')
       } else {
         format(x)
       }
@@ -18,7 +18,9 @@ bullets_with_header <- function(header, x) {
   }
   vals <- map_chr(x, as_simple)
 
-  cli::cli_li(paste0("{.field ", names(x), "}: ", vals))
+  for (i in seq_along(x)) {
+    cli::cli_li("{.field {names(x)[[i]]}}: {vals[[i]]}")
+  }
 }
 
 modify_list <- function(.x, ..., error_call = caller_env()) {
@@ -32,6 +34,8 @@ modify_list <- function(.x, ..., error_call = caller_env()) {
     )
   }
 
+
+
   out <- .x[!names(.x) %in% names(dots)]
   out <- c(out, compact(dots))
 
@@ -324,3 +328,24 @@ slice <- function(vector, start = 1, end = length(vector) + 1) {
     vector[start:(end - 1)]
   }
 }
+
+is_named_list <- function(x) {
+  is_list(x) && (is_named(x) || length(x) == 0)
+}
+
+pretty_json <- function(x) {
+  parsed <- tryCatch(
+    jsonlite::parse_json(x),
+    error = function(e) NULL
+  )
+  if (is.null(parsed)) {
+    x
+  } else {
+    jsonlite::toJSON(parsed, auto_unbox = TRUE, pretty = TRUE)
+  }
+}
+
+log_stream <- function(..., prefix = "<< ") {
+  out <- gsub("\n", paste0("\n", prefix), paste0(prefix, ..., collapse = ""))
+  cli::cat_line(out)
+}
