@@ -1,3 +1,3 @@
 testthat::set_state_inspector(function() {
-  getAllConnections()
+  list(connections = getAllConnections())
 })
